=====
Croud
=====

|ci| |coverage| |rtd| |pypi-version|

|

*Croud* is a *command-line interface* (CLI) tool for `CrateDB Cloud`_ ☁.

Installation
============

Using pip
---------

``croud`` can be installed using `pip`_::

    $ python3 -m pip install --user -U croud

To update, run::

    $ pip install -U croud

Contributing
============

This project is primarily maintained by Crate.io_, but we welcome community
contributions!

See the `developer docs`_ and the `contribution docs`_ for more information.

Help
====

- Read the `project docs`_
- Learn about `CrateDB Cloud`_
- Check out our `support channels`_

.. _contribution docs: https://github.com/crate/croud/blob/master/CONTRIBUTING.rst
.. _Crate.io: http://crate.io/
.. _developer docs: https://github.com/crate/croud/blob/master/DEVELOP.rst
.. _pip: https://pip.pypa.io/en/stable/
.. _project docs: https://crate.io/docs/cloud/cli/en/latest/
.. _support channels: https://crate.io/support/
.. _virtualenv: https://virtualenv.pypa.io/en/latest/
.. _CrateDB Cloud: https://crate.io/products/cratedb-cloud/


.. |ci| image:: https://github.com/crate/croud/actions/workflows/docs.yml/badge.svg
    :alt: CI status
    :scale: 100%
    :target: https://github.com/crate/croud/actions/workflows/docs.yml

.. |coverage| image:: https://codecov.io/gh/crate/croud/branch/master/graph/badge.svg
    :alt: Code coverage
    :scale: 100%
    :target: https://codecov.io/gh/crate/croud

.. |rtd| image:: https://readthedocs.org/projects/croud/badge/?version=latest
    :alt: Read The Docs status
    :scale: 100%
    :target: https://croud.readthedocs.io/en/latest/

.. |pypi-version| image:: https://badge.fury.io/py/croud.svg
    :alt: Most recent version on PyPI
    :scale: 100%
    :target: https://pypi.org/project/croud/

.. |python-versions| image:: https://img.shields.io/pypi/pyversions/croud.svg
    :alt: Supported Python versions
    :scale: 100%
    :target: https://pypi.org/project/croud/
